from setuptools import setup, find_packages

setup(
    name='pre5g',
    version='3.8',
    packages=find_packages(),
    description='An preprocessing package',
    author='SnehaM',
    author_email='1js20cs161@gmail.com',
    license='MIT',
    keywords=['example', 'package'],
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.6',
    ],
)